/*
 *
 * Example how to use the implementation "siscone_parton" of the SISCone jet algorithm.
 *
 *  Copyright (C) 2011 Stefan Weinzierl
 *
 */

#include <iostream>
#include <vector>

#include "fourvector.h"
#include "siscone_parton.h"

int main()
{
  using namespace siscone_jet_algorithm;

  // intialise the SISCone algorithm for maximally 4 final state particles
  int n_max = 4;
  siscone_parton<fourvector> jet_finder(n_max);

  // define the parameters for the SISCone algorithm
  double R      = 0.9;
  double f      = 0.5;
  int n_pass    = 0;
  double pt_min = 5.0;

  // some final-state momenta
  std::vector<fourvector> particles(4);
  particles[0] = fourvector(1.87116,-1.08275,1.33996,-0.730343);
  particles[1] = fourvector(33.3795,1.00171,28.1084,-17.9751);
  particles[2] = fourvector(32.4375,-12.8963,-13.154,26.6992);
  particles[3] = fourvector(22.3118,12.9774,-16.2944,-7.99375);

  // call the jet algorithm
  int n_jet = jet_finder.compute_jets( particles, R, f, n_pass, pt_min );

  // output
  std::cout << "Number of jets = " << n_jet << std::endl;
  for (int j=0; j<n_jet; j++) {
    std::cout << " Particle content of jet " << j << " : ";
    for (int i=0; i<n_max; i++) {
      if ( jet_finder.final_jets[j] & (1<<i) ) std::cout << i << " ";
    }
    std::cout << std::endl;
  }

  return 0;
}

